using System;
using System.Text;
using System.Xml;

namespace RSSReader.RSS
{

	/// <summary>
	/// Wraps information about the Image element in an RSS Channel feed
	/// </summary>
	public class RSSFeedImage
	{

		#region Private member variables 

		private string		title;
		private string		link;
		private string		url;
		private string		description;
		private string		width;
		private string		height;

		#endregion 

		#region Constructor 

		private RSSFeedImage() { }

		internal RSSFeedImage( XmlNode Element )
		{
			ReadFromXml( Element );
		}

		#endregion 

		#region Public properties 

		public string Title
		{
			get { return title; }
			set { title = value; }
		}

		public string Link
		{
			get { return link; }
			set { link = value; }
		}

		public string Url
		{
			get { return url; }
			set { url = value; }
		}
		
		public string Description 
		{
			get { return description; }
			set { description = value; }
		}

		public string Width
		{
			get { return width; }
			set { width = value; }
		}

		public string Height 
		{
			get { return height; }
			set { height = value; }
		}

		#endregion 

		#region Xml Serialization 

		public void WriteToXml( XmlTextWriter writer )
		{

			writer.WriteStartElement( "image" );

			XmlHelper.WriteSimpleElement( writer, "title", title );
			XmlHelper.WriteSimpleElement( writer, "link", link );
			XmlHelper.WriteSimpleElement( writer, "url", url );
			XmlHelper.WriteSimpleElement( writer, "description", description );
			XmlHelper.WriteSimpleElement( writer, "width", width );
			XmlHelper.WriteSimpleElement( writer, "height", height );

			writer.WriteEndElement();

		}

		public void ReadFromXml( XmlNode Element )
		{

			title = GetValue( Element, "", "title" );
			link = GetValue( Element, "", "link" );
			url = GetValue( Element, "", "url" );
			description = GetValue( Element, "", "description" );
			width = GetValue( Element, "", "width" );
			height = GetValue( Element, "", "height" );

		}

		#endregion 

		#region Private utility methods 

		private string GetValue( XmlNode Node, string DefaultValue, params string[] ElementNames )
		{

			if( ElementNames == null || ElementNames.Length == 0 )
				throw new ArgumentException( "You must provide an Element Name or a list of Element Names", "ElementNames" );

			foreach( string elementName in ElementNames )
			{

				XmlNode node = Node.SelectSingleNode( elementName );
				if( node != null )
					return node.InnerText;

			}

			return DefaultValue;

		}

		#endregion 

	}

}
